@@ -2,7 +2,8 @@ from glQiwiApi.qiwi.clients.maps.client import QiwiMaps
 from glQiwiApi.qiwi.clients.p2p.client import QiwiP2PClient
 from glQiwiApi.qiwi.clients.wallet.client import QiwiWallet
 from glQiwiApi.qiwi.clients.wrapper import QiwiWrapper
-from .core.cache import InMemoryCacheStorage, APIResponsesCacheInvalidationStrategy
+
+from .core.cache import APIResponsesCacheInvalidationStrategy, InMemoryCacheStorage
 from .core.cache.storage import CacheStorage
 from .yoo_money import YooMoneyAPI
 
@@ -18,7 +19,7 @@ def default_cache_storage() -> CacheStorage:
     return InMemoryCacheStorage(invalidate_strategy=APIResponsesCacheInvalidationStrategy())
 
 
-__version__ = "2.0.8"
+__version__ = "2.10"
 
 __all__ = (
     # clients
