@@ -1,4 +1,4 @@
-from typing import List, ClassVar
+from typing import ClassVar, List
 
 from pydantic import conint, parse_obj_as
 
