@@ -1,4 +1,4 @@
-from typing import ClassVar, Dict, Any
+from typing import Any, ClassVar, Dict
 
 from pydantic import Field
 
