@@ -1,9 +1,9 @@
 from json import JSONDecodeError
-from typing import ClassVar, Any
+from typing import Any, ClassVar
 
 from pydantic import Field
 
-from glQiwiApi.core.abc.api_method import ReturningType, Request
+from glQiwiApi.core.abc.api_method import Request, ReturningType
 from glQiwiApi.core.session.holder import HTTPResponse
 from glQiwiApi.qiwi.base import QiwiAPIMethod
 from glQiwiApi.qiwi.exceptions import QiwiAPIError
