@@ -1,9 +1,9 @@
 import time
-from typing import ClassVar, Dict, Any, Union
+from typing import Any, ClassVar, Dict, Union
 
 from pydantic import Field
 
-from glQiwiApi.core.abc.api_method import RuntimeValue, Request
+from glQiwiApi.core.abc.api_method import Request, RuntimeValue
 from glQiwiApi.qiwi.base import QiwiAPIMethod
 from glQiwiApi.qiwi.clients.wallet.types import PaymentInfo
 
