@@ -1,4 +1,4 @@
-from typing import ClassVar, Any
+from typing import Any, ClassVar
 
 from pydantic import Field
 
